@@ -2,13 +2,13 @@ package Perl::Critic::Policy::Plicease::ProhibitUnicodeDigitInRegexp;
 
 use strict;
 use warnings;
-use 5.008001;
+use 5.010001;
 use Perl::Critic::Utils qw( $SEVERITY_LOW );
 use PPIx::Regexp;
 use base qw( Perl::Critic::Policy );
 
 # ABSTRACT: Prohibit non-ASCII \d in regular expressions
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
 use constant DESC => 'Using non-ASCII \d';
@@ -61,7 +61,18 @@ Perl::Critic::Policy::Plicease::ProhibitUnicodeDigitInRegexp - Prohibit non-ASCI
 
 =head1 VERSION
 
-version 0.04
+version 0.05
+
+=head1 SYNOPSIS
+
+perlcriticrc:
+
+ [Plicease::ProhibitUnicodeDigitInRegexp]
+
+code:
+
+ /\d/;      # not ok
+ /[0-9]/;   # ok
 
 =head1 DESCRIPTION
 
@@ -113,7 +124,7 @@ Ville Skyttä (SCOP)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Graham Ollis.
+This software is copyright (c) 2019-2024 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
